/*
 * Copyright(C) OASIS(R) 2005,2009. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.
 */
package test.scaclient.systemproperty;

import static org.junit.Assert.assertEquals;

import java.net.URI;

import org.junit.Before;
import org.junit.Test;
import org.oasisopen.sca.NoSuchDomainException;
import org.oasisopen.sca.NoSuchServiceException;
import org.oasisopen.sca.client.SCAClient;
import org.oasisopen.sca.client.SCAClientFactory;

import com.helloservice.HelloService;
import com.vendor.scaimpl.VendorBootstrap;
import com.vendor.scaimpl.VendorSCAClientImpl;

public class TestSettingImplUsingSystemProperty
{
    private String serviceURI = "SomeHelloServiceURI";
    private URI domainURI;

    @Before
    public void setup() throws Exception
    {
        VendorBootstrap.bootstrap();
        domainURI = new URI("SomeDomainURI");
    }

    
    /**
     * Test that vendor provided implementation can be looked up by default.
     */
    @Test
    public void testGetVendorImpl() throws NoSuchServiceException, NoSuchDomainException {
        
        // Get SCAClient - will resolve to Vendors implementation
        final SCAClient scaClient = SCAClientFactory.newInstance();
        assertEquals(scaClient.getClass().getName(), VendorSCAClientImpl.class.getName());
        
        // Test that service lookup works
        final HelloService helloService = scaClient.getService(HelloService.class, serviceURI, domainURI);
        final String reply = helloService.sayHello("Mark");
        assertEquals("Hello Mark", reply);
    }
    
}
